from threading import Thread, Event
import time


class MockProcess(Thread):

    """Mock up a thread to play around with."""

    def __init__(self, config, q, logger, callback=None):
        Thread.__init__(self)
        self._config = config
        self._cb = callback
        self._log = logger
        self._q = q
        self.cooldown = Event()
        self.exit = Event()

    def run(self):
        data = [{'config': {'heater': 0, 'bean_temp': 395.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 437.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.659656816666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.659656816666667}, {'config': {'heater': 0, 'bean_temp': 395.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 437.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.648177933333333, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.648177933333333}, {'config': {'heater': 0, 'bean_temp': 395.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 437.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.63670905, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.63670905}, {'config': {'heater': 0, 'bean_temp': 395.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 435.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.625218616666666, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.625218616666666}, {'config': {'heater': 0, 'bean_temp': 395.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 435.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.610269983333334, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.610269983333334}, {'config': {'heater': 0, 'bean_temp': 395.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 435.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.5972025, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.5972025}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 435.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.584152766666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.584152766666667}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 435.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.570760216666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.570760216666667}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 435.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.5592822, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.5592822}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 435.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.547797316666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.547797316666667}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 433.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 12.534451383333334, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.534451383333334}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 433.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 12.522977533333334, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.522977533333334}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 433.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 12.511491366666666, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.511491366666666}, {'config': {'heater': 0, 'bean_temp': 393.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 433.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 12.500032683333334, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.500032683333334}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 433.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 12.48855645, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.48855645}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 433.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 12.476787883333333, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.476787883333333}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 433.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 12.463707316666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.463707316666667}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.452236233333334, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.452236233333334}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.440760266666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.440760266666667}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.429022383333335, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.429022383333335}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.415919216666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.415919216666667}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.404443966666665, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.404443966666665}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.392961666666668, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.392961666666668}, {'config': {'heater': 0, 'bean_temp': 392.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.381214066666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.381214066666667}, {'config': {'heater': 0, 'bean_temp': 390.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.36974855, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.36974855}, {'config': {'heater': 0, 'bean_temp': 390.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 431.6, 'chaff_tray': 1, 'fan': 0, 'time': 12.358255716666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.358255716666667}, {'config': {'heater': 0, 'bean_temp': 390.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.331833766666668, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.331833766666668}, {'config': {'heater': 0, 'bean_temp': 390.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.320347566666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.320347566666667}, {'config': {'heater': 0, 'bean_temp': 390.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.3088692, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.3088692}, {'config': {'heater': 0, 'bean_temp': 390.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.297388716666667, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.297388716666667}, {'config': {'heater': 0, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.285657950000001, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.285657950000001}, {'config': {'heater': 0, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.25955535, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.25955535}, {'config': {'heater': 0, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.248001350000001, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.248001350000001}, {'config': {'heater': 0, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.236282899999999, 'solenoid': 1, 'cooling_motor': 1}, 'time': 12.236282899999999}, {'config': {'heater': 85, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.223173683333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.223173683333332}, {'config': {'heater': 85, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.211740966666667, 'solenoid': 0, 'cooling_motor': 0}, 'event': 'Drop Coffee', 'time': 12.216792766666666}, {'config': {'heater': 85, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.211740966666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.211740966666667}, {'config': {'heater': 85, 'bean_temp': 388.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 429.8, 'chaff_tray': 1, 'fan': 0, 'time': 12.200216683333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.200216683333334}, {'config': {'heater': 85, 'bean_temp': 386.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.185265233333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.185265233333332}, {'config': {'heater': 85, 'bean_temp': 386.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.17378725, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.17378725}, {'config': {'heater': 85, 'bean_temp': 386.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.162308466666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.162308466666667}, {'config': {'heater': 85, 'bean_temp': 386.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.14735645, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.14735645}, {'config': {'heater': 85, 'bean_temp': 386.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.1359014, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.1359014}, {'config': {'heater': 85, 'bean_temp': 386.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.12439905, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.12439905}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.109467200000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.109467200000001}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.097967583333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.097967583333334}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.0865169, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.0865169}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.073161033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.073161033333333}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.06006115, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.06006115}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 428.0, 'chaff_tray': 1, 'fan': 0, 'time': 12.048688883333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.048688883333334}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.035245983333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.035245983333335}, {'config': {'heater': 85, 'bean_temp': 384.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.0237556, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.0237556}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.0122742, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.0122742}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 12.000794633333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 12.000794633333333}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.989062266666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.989062266666668}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.975966883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.975966883333333}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.9644978, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.9644978}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.953018733333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.953018733333332}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.93805855, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.93805855}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.926591916666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.926591916666666}, {'config': {'heater': 85, 'bean_temp': 383.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.910025166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.910025166666665}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 426.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.8985479, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.8985479}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.885470883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.885470883333333}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.872130416666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.872130416666666}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.8606418, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.8606418}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.849170249999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.849170249999998}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.835872883333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.835872883333334}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.8243387, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.8243387}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.812891483333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.812891483333335}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.799774666666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.799774666666668}, {'config': {'heater': 85, 'bean_temp': 381.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.78802325, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.78802325}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.776623983333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.776623983333334}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.763463116666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.763463116666665}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.75199295, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.75199295}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.740235816666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.740235816666665}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 424.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.728769516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.728769516666667}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.717350033333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.717350033333334}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.705805683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.705805683333333}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.694329766666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.694329766666668}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.680985066666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.680985066666667}, {'config': {'heater': 85, 'bean_temp': 379.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.66951385, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.66951385}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.658026266666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.658026266666667}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.643066416666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.643066416666667}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.631597816666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.631597816666666}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.620122433333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.620122433333334}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.605157116666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.605157116666668}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.59367825, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.59367825}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.582281166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.582281166666666}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.567390516666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.567390516666668}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.555768733333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.555768733333334}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 422.6, 'chaff_tray': 1, 'fan': 0, 'time': 11.54428895, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.54428895}, {'config': {'heater': 85, 'bean_temp': 377.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.5312085, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.5312085}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.519474183333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.519474183333333}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.50802475, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.50802475}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.493310566666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.493310566666667}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.481549766666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.481549766666665}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.4700853, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.4700853}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.455398516666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.455398516666666}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.443909999999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.443909999999999}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.432164550000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.432164550000001}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.419084866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.419084866666667}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.4076061, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.4076061}, {'config': {'heater': 85, 'bean_temp': 375.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.396136649999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.396136649999999}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 420.8, 'chaff_tray': 1, 'fan': 0, 'time': 11.382795333333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.382795333333332}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.369695916666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.369695916666666}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.358227166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.358227166666667}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.34646945, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.34646945}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.334990383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.334990383333333}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.3235204, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.3235204}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.312032333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.312032333333333}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.30055195, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.30055195}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.288805483333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.288805483333334}, {'config': {'heater': 85, 'bean_temp': 374.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.277338583333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.277338583333334}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.264250616666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.264250616666667}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.2527738, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.2527738}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.24105135, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.24105135}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.226346816666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.226346816666668}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.214869783333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.214869783333334}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.203123416666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.203123416666667}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.191630966666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.191630966666667}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 419.0, 'chaff_tray': 1, 'fan': 0, 'time': 11.180164583333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.180164583333333}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.168672233333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.168672233333332}, {'config': {'heater': 85, 'bean_temp': 372.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.157192766666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.157192766666666}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.145447066666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.145447066666666}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.133967416666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.133967416666668}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.120888666666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.120888666666668}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.1094061, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.1094061}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.09767155, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.09767155}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.086179433333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.086179433333333}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.069653983333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.069653983333334}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.056545783333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.056545783333332}, {'config': {'heater': 85, 'bean_temp': 370.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.045079433333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.045079433333333}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.030240566666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.030240566666667}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 417.2, 'chaff_tray': 1, 'fan': 0, 'time': 11.018638733333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.018638733333335}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 11.007186916666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 11.007186916666665}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.995678666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.995678666666667}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.984199516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.984199516666667}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.95618445, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.95618445}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.944428933333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.944428933333334}, {'config': {'heater': 85, 'bean_temp': 368.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.932962716666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.932962716666667}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.918268766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.918268766666667}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.906514166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.906514166666666}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.8950768, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.8950768}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.883554299999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.883554299999998}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.872082266666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.872082266666666}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.860612366666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.860612366666667}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.8488489, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.8488489}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.837369766666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.837369766666665}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.8258942, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.8258942}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 415.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.814423433333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.814423433333333}, {'config': {'heater': 85, 'bean_temp': 366.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.80293135, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.80293135}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.79119135, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.79119135}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.779727750000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.779727750000001}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.766636049999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.766636049999999}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.755145700000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.755145700000002}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.743399166666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.743399166666668}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.730333199999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.730333199999999}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.7188395, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.7188395}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.7074871, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.7074871}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.695879999999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.695879999999999}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.684161083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.684161083333333}, {'config': {'heater': 85, 'bean_temp': 365.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.67265325, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.67265325}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.661185933333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.661185933333334}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.649695066666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.649695066666668}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.638227616666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.638227616666667}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 413.6, 'chaff_tray': 1, 'fan': 0, 'time': 10.626470583333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.626470583333335}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.613390616666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.613390616666667}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.601921933333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.601921933333333}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.590428533333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.590428533333332}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.577155699999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.577155699999999}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.565632016666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.565632016666665}, {'config': {'heater': 85, 'bean_temp': 363.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.55412625, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.55412625}, {'config': {'heater': 85, 'bean_temp': 361.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.539181066666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.539181066666666}, {'config': {'heater': 85, 'bean_temp': 361.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.527691933333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.527691933333333}, {'config': {'heater': 85, 'bean_temp': 361.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.516235266666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.516235266666666}, {'config': {'heater': 85, 'bean_temp': 361.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.504733783333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.504733783333334}, {'config': {'heater': 85, 'bean_temp': 361.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.493254183333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.493254183333333}, {'config': {'heater': 85, 'bean_temp': 361.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.466824583333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.466824583333333}, {'config': {'heater': 85, 'bean_temp': 361.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 411.8, 'chaff_tray': 1, 'fan': 0, 'time': 10.455352466666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.455352466666666}, {'config': {'heater': 85, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.443599916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.443599916666667}, {'config': {'heater': 85, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.432120516666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.432120516666666}, {'config': {'heater': 85, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.420659183333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.420659183333333}, {'config': {'heater': 84, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.409171500000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.409171500000001}, {'config': {'heater': 82, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.3976825, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.3976825}, {'config': {'heater': 80, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.385949316666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.385949316666666}, {'config': {'heater': 80, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.3744668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.3744668}, {'config': {'heater': 80, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.362980083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.362980083333333}, {'config': {'heater': 80, 'bean_temp': 359.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.351496983333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.351496983333334}, {'config': {'heater': 80, 'bean_temp': 357.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.340017483333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.340017483333332}, {'config': {'heater': 80, 'bean_temp': 357.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.3282713, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.3282713}, {'config': {'heater': 80, 'bean_temp': 357.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.316807616666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.316807616666667}, {'config': {'heater': 80, 'bean_temp': 357.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.305334533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.305334533333333}, {'config': {'heater': 80, 'bean_temp': 357.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.293839683333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.293839683333335}, {'config': {'heater': 80, 'bean_temp': 357.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 410.0, 'chaff_tray': 1, 'fan': 0, 'time': 10.282369166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.282369166666665}, {'config': {'heater': 80, 'bean_temp': 357.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.2708742, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.2708742}, {'config': {'heater': 80, 'bean_temp': 356.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.244454916666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.244454916666665}, {'config': {'heater': 80, 'bean_temp': 356.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.232976533333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.232976533333334}, {'config': {'heater': 80, 'bean_temp': 356.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.221217866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.221217866666667}, {'config': {'heater': 80, 'bean_temp': 356.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.20974645, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.20974645}, {'config': {'heater': 80, 'bean_temp': 356.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.198272683333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.198272683333332}, {'config': {'heater': 80, 'bean_temp': 356.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.186781516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.186781516666667}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.175332283333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.175332283333335}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.161954533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.161954533333333}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.150475833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.150475833333333}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.138994833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.138994833333333}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.12564675, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.12564675}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.114168033333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.114168033333334}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.102698716666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.102698716666668}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.091206933333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.091206933333332}, {'config': {'heater': 80, 'bean_temp': 354.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.079726066666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.079726066666666}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.068274733333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.068274733333334}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.056515516666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.056515516666668}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 408.2, 'chaff_tray': 1, 'fan': 0, 'time': 10.045023716666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.045023716666666}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.033548033333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.033548033333334}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.022062633333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.022062633333332}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 10.010584633333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 10.010584633333334}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.998838766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.998838766666667}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.987360466666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.987360466666667}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.974278116666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.974278116666666}, {'config': {'heater': 80, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.962810350000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.962810350000002}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.951053583333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.951053583333334}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.937974816666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.937974816666667}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.926507533333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.926507533333334}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.915039283333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.915039283333334}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 406.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.90326595, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.90326595}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.89178855, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.89178855}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.88031935, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.88031935}, {'config': {'heater': 80, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.868830283333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.868830283333333}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.857358116666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.857358116666667}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.845614533333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.845614533333332}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.83412445, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.83412445}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.821042466666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.821042466666666}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.809563516666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.809563516666666}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.7978324, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.7978324}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.786352816666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.786352816666666}, {'config': {'heater': 80, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.774857816666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.774857816666668}, {'config': {'heater': 80, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 404.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.761781833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.761781833333334}, {'config': {'heater': 80, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.7484308, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.7484308}, {'config': {'heater': 80, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.733745699999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.733745699999998}, {'config': {'heater': 80, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.720404, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.720404}, {'config': {'heater': 80, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.708917166666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.708917166666668}, {'config': {'heater': 80, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.695848250000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.695848250000001}, {'config': {'heater': 80, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.684379033333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.684379033333332}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.672611533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.672611533333333}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.659526833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.659526833333333}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.648060166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.648060166666665}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.636585316666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.636585316666666}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.624836966666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.624836966666667}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 402.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.613356616666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.613356616666666}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.601879366666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.601879366666667}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.590385683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.590385683333333}, {'config': {'heater': 80, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.578910566666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.578910566666668}, {'config': {'heater': 79, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.565571516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.565571516666667}, {'config': {'heater': 79, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.554088216666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.554088216666665}, {'config': {'heater': 76, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.540996233333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.540996233333335}, {'config': {'heater': 78, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.529256333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.529256333333333}, {'config': {'heater': 76, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.517770916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.517770916666667}, {'config': {'heater': 90, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.493215216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.493215216666666}, {'config': {'heater': 90, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.481476066666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.481476066666666}, {'config': {'heater': 90, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.468382516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.468382516666667}, {'config': {'heater': 90, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 401.0, 'chaff_tray': 1, 'fan': 0, 'time': 9.456910316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.456910316666667}, {'config': {'heater': 90, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.44546305, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.44546305}, {'config': {'heater': 90, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.433689933333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.433689933333333}, {'config': {'heater': 90, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.42220145, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.42220145}, {'config': {'heater': 90, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.410727216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.410727216666666}, {'config': {'heater': 90, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.399238216666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.399238216666667}, {'config': {'heater': 90, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 10, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.38590305, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.38590305}, {'config': {'heater': 90, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.372818316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.372818316666667}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.361331733333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.361331733333333}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.349849216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.349849216666666}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.336502733333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.336502733333333}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.323427366666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.323427366666666}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 399.2, 'chaff_tray': 1, 'fan': 0, 'time': 9.3119452, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.3119452}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.300194983333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.300194983333334}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.288721966666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.288721966666666}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.2772495, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.2772495}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.264185383333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.264185383333334}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.252418116666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.252418116666666}, {'config': {'heater': 90, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.240926199999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.240926199999999}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.22786105, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.22786105}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.216367866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.216367866666667}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.189956800000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.189956800000001}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 397.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 9.178458683333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.178458683333334}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.166718233333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.166718233333334}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.15364585, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.15364585}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.14228475, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.14228475}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.130671900000001, 'solenoid': 0, 'cooling_motor': 0}, 'event': 'First Crack', 'time': 9.136212266666666}, {'config': {'heater': 90, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.130671900000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.130671900000001}, {'config': {'heater': 90, 'bean_temp': 336.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.118926733333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.118926733333332}, {'config': {'heater': 90, 'bean_temp': 336.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.107444316666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.107444316666665}, {'config': {'heater': 90, 'bean_temp': 336.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.095971316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.095971316666667}, {'config': {'heater': 90, 'bean_temp': 336.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.084489033333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.084489033333334}, {'config': {'heater': 90, 'bean_temp': 336.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.072753416666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.072753416666666}, {'config': {'heater': 90, 'bean_temp': 336.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.061280933333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.061280933333334}, {'config': {'heater': 90, 'bean_temp': 336.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 395.6, 'chaff_tray': 1, 'fan': 0, 'time': 9.049784466666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.049784466666667}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.024963233333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.024963233333333}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.01349295, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.01349295}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 9.002001116666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 9.002001116666666}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.99051895, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.99051895}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.979041016666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.979041016666667}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.967300533333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.967300533333335}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.9558163, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.9558163}, {'config': {'heater': 90, 'bean_temp': 334.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.944351016666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.944351016666667}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.93287045, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.93287045}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.92111515, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.92111515}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.909632616666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.909632616666666}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.8981636, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.8981636}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 393.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.886705883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.886705883333333}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.87520035, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.87520035}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.86184545, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.86184545}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.850388299999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.850388299999999}, {'config': {'heater': 90, 'bean_temp': 332.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.838884033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.838884033333333}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.800977499999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.800977499999998}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.789497216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.789497216666666}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.77775505, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.77775505}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.766271466666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.766271466666666}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.754794416666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.754794416666666}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.743316116666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.743316116666668}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.731836233333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.731836233333333}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.718493016666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.718493016666667}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.7038189, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.7038189}, {'config': {'heater': 90, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.69232725, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.69232725}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.6789779, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.6789779}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.667504483333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.667504483333333}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.6560208, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.6560208}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.644272633333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.644272633333333}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.6328023, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.6328023}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.62132815, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.62132815}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.608232916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.608232916666667}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.5964928, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.5964928}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.585007999999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.585007999999998}, {'config': {'heater': 90, 'bean_temp': 327.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 8.573534033333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.573534033333335}, {'config': {'heater': 90, 'bean_temp': 325.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.56205035, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.56205035}, {'config': {'heater': 90, 'bean_temp': 325.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.550305033333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.550305033333332}, {'config': {'heater': 90, 'bean_temp': 325.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.538821916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.538821916666667}, {'config': {'heater': 90, 'bean_temp': 325.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.52736735, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.52736735}, {'config': {'heater': 90, 'bean_temp': 325.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.515866433333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.515866433333334}, {'config': {'heater': 90, 'bean_temp': 325.40000000000003, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.504402716666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.504402716666668}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.49264235, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.49264235}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.481167783333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.481167783333335}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.469691816666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.469691816666666}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.459798049999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.459798049999998}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.4464544, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.4464544}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.434988116666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.434988116666666}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.423513033333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.423513033333332}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 8.41361505, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.41361505}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.402154666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.402154666666666}, {'config': {'heater': 90, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.390671433333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.390671433333333}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.378910866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.378910866666667}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.367432783333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.367432783333333}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.355962033333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.355962033333332}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.344478250000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.344478250000002}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.33299235, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.33299235}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.3228528, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.3228528}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.311368466666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.311368466666666}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.299885616666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.299885616666666}, {'config': {'heater': 90, 'bean_temp': 321.8, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.28842035, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.28842035}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 8.276930433333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.276930433333332}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.265183033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.265183033333333}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.255310033333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.255310033333334}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.243827616666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.243827616666666}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.219262216666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.219262216666667}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.20752025, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.20752025}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.196042716666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.196042716666666}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.184561266666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.184561266666666}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.174684866666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.174684866666666}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.16320385, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.16320385}, {'config': {'heater': 90, 'bean_temp': 320.0, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.151471016666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.151471016666667}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.139995883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.139995883333333}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.128500333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.128500333333333}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.117020616666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.117020616666666}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.105552566666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.105552566666665}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 8.09380555, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.09380555}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.082318166666669, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.082318166666669}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.07085275, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.07085275}, {'config': {'heater': 90, 'bean_temp': 318.2, 'drum_motor': 1, 'main_fan': 7, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.0593563, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.0593563}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.034529216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.034529216666666}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.023057266666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.023057266666667}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 8.011592133333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 8.011592133333332}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.9867422, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.9867422}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.975262316666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.975262316666665}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.963790933333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.963790933333334}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.952041816666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.952041816666668}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.9405574166666675, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.9405574166666675}, {'config': {'heater': 90, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.929109933333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.929109933333333}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.917602266666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.917602266666666}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.906124199999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.906124199999999}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.891171733333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.891171733333332}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.879695766666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.879695766666666}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.868222616666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.868222616666666}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.843382666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.843382666666665}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.831902083333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.831902083333334}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.820158883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.820158883333333}, {'config': {'heater': 90, 'bean_temp': 314.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.808691783333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.808691783333332}, {'config': {'heater': 90, 'bean_temp': 312.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.798797866666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.798797866666666}, {'config': {'heater': 90, 'bean_temp': 312.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.78732035, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.78732035}, {'config': {'heater': 90, 'bean_temp': 312.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.77587595, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.77587595}, {'config': {'heater': 90, 'bean_temp': 312.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.764362766666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.764362766666666}, {'config': {'heater': 90, 'bean_temp': 312.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.7510195333333325, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.7510195333333325}, {'config': {'heater': 90, 'bean_temp': 312.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.7379396499999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.7379396499999995}, {'config': {'heater': 90, 'bean_temp': 312.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.7264608500000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.7264608500000005}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.714706566666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.714706566666667}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.703228833333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.703228833333332}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.693363250000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.693363250000001}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.681871916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.681871916666667}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.671994816666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.671994816666665}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.660510683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.660510683333333}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.6487657166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.6487657166666665}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 7.6372884333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.6372884333333335}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.625807933333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.625807933333332}, {'config': {'heater': 90, 'bean_temp': 311.0, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.6143292166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.6143292166666665}, {'config': {'heater': 90, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.602846816666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.602846816666666}, {'config': {'heater': 90, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.59110375, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.59110375}, {'config': {'heater': 90, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.579715066666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.579715066666665}, {'config': {'heater': 90, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.556667016666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.556667016666665}, {'config': {'heater': 90, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.54492945, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.54492945}, {'config': {'heater': 90, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.5350392500000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.5350392500000005}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.523569816666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.523569816666667}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.512082600000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.512082600000001}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.489122, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.489122}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.4774394, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.4774394}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 7.465898233333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.465898233333332}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.454417016666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.454417016666666}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.44298425, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.44298425}, {'config': {'heater': 90, 'bean_temp': 307.40000000000003, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.431194033333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.431194033333334}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.41972045, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.41972045}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.408244116666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.408244116666667}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.396757166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.396757166666667}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.386877983333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.386877983333333}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.375416550000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.375416550000001}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.3636522666666675, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.3636522666666675}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.35219405, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.35219405}, {'config': {'heater': 90, 'bean_temp': 305.6, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.340703716666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.340703716666667}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.327612333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.327612333333333}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 7.3174657666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.3174657666666665}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.305999699999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.305999699999999}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.2814253666666655, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.2814253666666655}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.269686716666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.269686716666666}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.258200516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.258200516666667}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.248322616666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.248322616666666}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.2368440666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.2368440666666665}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 5, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.225379800000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.225379800000001}, {'config': {'heater': 90, 'bean_temp': 303.8, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.215493833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.215493833333333}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.20402455, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.20402455}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.193863233333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.193863233333333}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.182383633333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.182383633333334}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.172512533333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.172512533333334}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.161028183333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.161028183333334}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.138072733333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.138072733333333}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 7.126321383333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.126321383333332}, {'config': {'heater': 90, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.114845600000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.114845600000001}, {'config': {'heater': 90, 'bean_temp': 300.2, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.103362166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.103362166666667}, {'config': {'heater': 90, 'bean_temp': 300.2, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.093484166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.093484166666666}, {'config': {'heater': 90, 'bean_temp': 300.2, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.0820069666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.0820069666666665}, {'config': {'heater': 90, 'bean_temp': 300.2, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.070277483333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.070277483333333}, {'config': {'heater': 90, 'bean_temp': 300.2, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.058781266666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.058781266666667}, {'config': {'heater': 90, 'bean_temp': 300.2, 'drum_motor': 1, 'main_fan': 4, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.047304799999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.047304799999999}, {'config': {'heater': 90, 'bean_temp': 298.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 7.010995983333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 7.010995983333334}, {'config': {'heater': 90, 'bean_temp': 298.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.999517, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.999517}, {'config': {'heater': 90, 'bean_temp': 298.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.989648116666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.989648116666667}, {'config': {'heater': 90, 'bean_temp': 298.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.978160283333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.978160283333334}, {'config': {'heater': 90, 'bean_temp': 298.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.96827875, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.96827875}, {'config': {'heater': 90, 'bean_temp': 298.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.956803716666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.956803716666667}, {'config': {'heater': 90, 'bean_temp': 298.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.945057216666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.945057216666667}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.92211195, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.92211195}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.910620383333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.910620383333334}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.90073965, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.90073965}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.888997483333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.888997483333333}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.8644346, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.8644346}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.852953783333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.852953783333334}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.84121435, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.84121435}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.8297405499999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.8297405499999995}, {'config': {'heater': 90, 'bean_temp': 296.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.818264466666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.818264466666666}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.806769416666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.806769416666667}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.795292633333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.795292633333333}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.783546333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.783546333333334}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.772080133333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.772080133333334}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.76219005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.76219005}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.750716533333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.750716533333334}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.739239366666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.739239366666666}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.727482683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.727482683333333}, {'config': {'heater': 90, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.716005249999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.716005249999999}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.7061317, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.7061317}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.694645333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.694645333333333}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 6.683177083333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.683177083333334}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.6716881, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.6716881}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.661550816666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.661550816666666}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.650085750000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.650085750000001}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.638593266666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.638593266666667}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.628715883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.628715883333333}, {'config': {'heater': 90, 'bean_temp': 293.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.6172470500000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.6172470500000005}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.605747516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.605747516666667}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.594000016666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.594000016666667}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.5825334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.5825334}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.5726448500000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.5726448500000005}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.561180566666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.561180566666667}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.549690666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.549690666666667}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.538207083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.538207083333333}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 6.5248591000000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.5248591000000005}, {'config': {'heater': 90, 'bean_temp': 291.2, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.511775683333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.511775683333334}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.500301483333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.500301483333333}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.488555916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.488555916666667}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.4754686, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.4754686}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.462416983333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.462416983333333}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.450641083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.450641083333333}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.439161100000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.439161100000001}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.429294, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.429294}, {'config': {'heater': 90, 'bean_temp': 289.40000000000003, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.41781535, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.41781535}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.406335183333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.406335183333334}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.3964438333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.3964438333333336}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.384979283333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.384979283333333}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.37323455, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.37323455}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.3633408000000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.3633408000000005}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.351870483333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.351870483333333}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.3419859, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.3419859}, {'config': {'heater': 90, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.330518933333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.330518933333334}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.320627433333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.320627433333333}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 6.309147466666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.309147466666667}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.2992673833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.2992673833333335}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.28752445, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.28752445}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.277653, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.277653}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.2661856333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.2661856333333334}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.256287866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.256287866666667}, {'config': {'heater': 90, 'bean_temp': 285.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.244827383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.244827383333333}, {'config': {'heater': 90, 'bean_temp': 284.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.22159075, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.22159075}, {'config': {'heater': 90, 'bean_temp': 284.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.210105833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.210105833333333}, {'config': {'heater': 90, 'bean_temp': 284.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.200225916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.200225916666667}, {'config': {'heater': 90, 'bean_temp': 284.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.188748133333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.188748133333333}, {'config': {'heater': 90, 'bean_temp': 284.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.177272083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.177272083333333}, {'config': {'heater': 90, 'bean_temp': 284.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.1673887, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.1673887}, {'config': {'heater': 90, 'bean_temp': 284.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 6.155949666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.155949666666667}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.144167216666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.144167216666667}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.134288166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.134288166666667}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.122822966666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.122822966666666}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.111329933333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.111329933333334}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.101458766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.101458766666667}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.089974033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.089974033333333}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.076628966666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.076628966666666}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.066745766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.066745766666667}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.055268533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.055268533333333}, {'config': {'heater': 90, 'bean_temp': 282.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.045393316666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.045393316666666}, {'config': {'heater': 90, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.03392635, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.03392635}, {'config': {'heater': 90, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.022429483333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.022429483333334}, {'config': {'heater': 90, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.0125507166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.0125507166666665}, {'config': {'heater': 90, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 6.000813583333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 6.000813583333334}, {'config': {'heater': 90, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 5.977847033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.977847033333333}, {'config': {'heater': 90, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 5.967969533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.967969533333333}, {'config': {'heater': 90, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 5.9564889333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.9564889333333335}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 5.946625216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.946625216666666}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.936743266666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.936743266666666}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.925260949999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.925260949999999}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.913508449999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.913508449999999}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.903637716666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.903637716666666}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.89375405, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.89375405}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.8822835499999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.8822835499999995}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.872394466666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.872394466666666}, {'config': {'heater': 90, 'bean_temp': 278.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.8609189, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.8609189}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.837690033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.837690033333333}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.827818333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.827818333333334}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.816349866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.816349866666667}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.80646075, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.80646075}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.796576633333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.796576633333333}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.78509705, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.78509705}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.7752272, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.7752272}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 5.763744366666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.763744366666667}, {'config': {'heater': 90, 'bean_temp': 276.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.753865033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.753865033333333}, {'config': {'heater': 90, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.742405833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.742405833333334}, {'config': {'heater': 90, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.7191583999999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.7191583999999995}, {'config': {'heater': 90, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.696212666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.696212666666667}, {'config': {'heater': 90, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.686317316666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.686317316666666}, {'config': {'heater': 90, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.674579733333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.674579733333333}, {'config': {'heater': 90, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.66469245, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.66469245}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.653233083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.653233083333333}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.640197850000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.640197850000001}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.6302534, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.6302534}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.6187768, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.6187768}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.6070425833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.6070425833333335}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.595551216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.595551216666666}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.584107516666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.584107516666666}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.572592183333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.572592183333333}, {'config': {'heater': 90, 'bean_temp': 273.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.562714033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.562714033333333}, {'config': {'heater': 90, 'bean_temp': 271.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.537886666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.537886666666666}, {'config': {'heater': 90, 'bean_temp': 271.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 5.52647755, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.52647755}, {'config': {'heater': 90, 'bean_temp': 271.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.5149301, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.5149301}, {'config': {'heater': 90, 'bean_temp': 271.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.505046933333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.505046933333333}, {'config': {'heater': 90, 'bean_temp': 271.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.493568166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.493568166666666}, {'config': {'heater': 90, 'bean_temp': 271.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.483693766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.483693766666667}, {'config': {'heater': 90, 'bean_temp': 271.4, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.4719513, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.4719513}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.4620636, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.4620636}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.45060425, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.45060425}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.4407113, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.4407113}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.429231866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.429231866666667}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.417760383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.417760383333333}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.406002833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.406002833333333}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.39452485, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.39452485}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.3830612, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.3830612}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.3731655499999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.3731655499999995}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.363293100000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.363293100000001}, {'config': {'heater': 90, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.35181035, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.35181035}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.340336949999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.340336949999999}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.330449416666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.330449416666666}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.31870495, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.31870495}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.308834766666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.308834766666666}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.298965583333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.298965583333333}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.289091383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.289091383333333}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.279194883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.279194883333333}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.269333166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.269333166666667}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.259443766666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.259443766666666}, {'config': {'heater': 90, 'bean_temp': 267.8, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.24797305, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.24797305}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 5.238080766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.238080766666667}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.215135399999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.215135399999999}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.204976783333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.204976783333334}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.195100966666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.195100966666667}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.1852207833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.1852207833333335}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.175347966666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.175347966666666}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.165475316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.165475316666667}, {'config': {'heater': 90, 'bean_temp': 266.0, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.15558785, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.15558785}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.145720316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.145720316666667}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.135830400000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.135830400000001}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.125959966666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.125959966666667}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.11607465, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.11607465}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.106208133333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.106208133333333}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.096318816666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.096318816666667}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.086450433333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.086450433333334}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.07656555, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.07656555}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.066717683333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.066717683333334}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.05681435, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.05681435}, {'config': {'heater': 90, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 3, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.04693155, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.04693155}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 2, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.037058083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.037058083333333}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.027173983333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.027173983333333}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.017302066666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.017302066666667}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 5.007420033333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 5.007420033333333}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.9975496, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.9975496}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.987662766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.987662766666667}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.9777948499999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.9777948499999995}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.967908666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.967908666666667}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.958035316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.958035316666667}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.948152250000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.948152250000001}, {'config': {'heater': 90, 'bean_temp': 262.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.938016683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.938016683333333}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.928132133333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.928132133333333}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 4.9182554666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.9182554666666665}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.90838605, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.90838605}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.8984971, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.8984971}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.8886258, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.8886258}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.878742866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.878742866666667}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.8688738, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.8688738}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.8589861, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.8589861}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.849127666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.849127666666666}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.8392312833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.8392312833333335}, {'config': {'heater': 90, 'bean_temp': 260.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.829363333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.829363333333333}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.817876516666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.817876516666667}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.808012716666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.808012716666667}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.798121266666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.798121266666667}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.788250966666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.788250966666666}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.7783640499999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.7783640499999995}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.768491466666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.768491466666666}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.758608983333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.758608983333334}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.748732683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.748732683333333}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.7385926000000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.7385926000000005}, {'config': {'heater': 90, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.728978883333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.728978883333334}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.718844083333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.718844083333334}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.7089564, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.7089564}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.6990859333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.6990859333333335}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.689200333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.689200333333333}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.679330416666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.679330416666667}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.667850216666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.667850216666666}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.6579696833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.6579696833333335}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.648085833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.648085833333334}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.638214783333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.638214783333334}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.6283303, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.6283303}, {'config': {'heater': 90, 'bean_temp': 257.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 4.618464149999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.618464149999999}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.608575816666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.608575816666667}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.598712466666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.598712466666667}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.588820833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.588820833333333}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.577084566666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.577084566666667}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.5672003, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.5672003}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.55734255, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.55734255}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.534360166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.534360166666667}, {'config': {'heater': 90, 'bean_temp': 255.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.52448615, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.52448615}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.513004783333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.513004783333333}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.50313925, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.50313925}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.4932444333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.4932444333333335}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.4815202, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.4815202}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.4716242, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.4716242}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.46014565, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.46014565}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.450269316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.450269316666667}, {'config': {'heater': 90, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.440386616666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.440386616666667}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.43051255, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.43051255}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.4206441666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.4206441666666665}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.410757966666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.410757966666667}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.400883266666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.400883266666667}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.389400816666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.389400816666667}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.379520266666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.379520266666666}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.369647783333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.369647783333334}, {'config': {'heater': 90, 'bean_temp': 251.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.3597774, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.3597774}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.349891466666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.349891466666667}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.3400183, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.3400183}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.330139133333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.330139133333334}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.3183879166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.3183879166666665}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 4.308511183333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.308511183333334}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.29864705, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.29864705}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.2887571, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.2887571}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.278909916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.278909916666667}, {'config': {'heater': 90, 'bean_temp': 249.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.269001516666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.269001516666666}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.2591295166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.2591295166666665}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.249244683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.249244683333333}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.239377166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.239377166666666}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.229487766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.229487766666667}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.219623883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.219623883333333}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.20973485, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.20973485}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.199862416666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.199862416666667}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.189983233333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.189983233333334}, {'config': {'heater': 90, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.180103683333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.180103683333333}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.170239166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.170239166666666}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.16034845, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.16034845}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.150481650000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.150481650000001}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.140593716666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.140593716666666}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.130725383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.130725383333333}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.120835183333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.120835183333333}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.11096445, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.11096445}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.100816483333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.100816483333333}, {'config': {'heater': 90, 'bean_temp': 246.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.0909518333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.0909518333333335}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.081058116666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.081058116666666}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.071185549999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.071185549999999}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.0613047333333325, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.0613047333333325}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.049868066666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.049868066666666}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.039946850000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.039946850000001}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.0300812, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.0300812}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.020191883333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.020191883333333}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 4.008723116666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 4.008723116666667}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 3.9988400833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.9988400833333335}, {'config': {'heater': 90, 'bean_temp': 244.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 3.988963233333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.988963233333334}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 3.9790769500000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.9790769500000005}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 3.969204416666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.969204416666667}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 3.9593223, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.9593223}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.9494475666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.9494475666666666}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.9395825333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.9395825333333336}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.9294280666666657, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.9294280666666657}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.919558566666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.919558566666667}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.9096682166666676, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.9096682166666676}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.8997944333333328, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.8997944333333328}, {'config': {'heater': 90, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.8899116666666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.8899116666666664}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.8800423833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.8800423833333335}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.870155583333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.870155583333333}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.860286583333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.860286583333334}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.8504031666666663, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.8504031666666663}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.84052635, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.84052635}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.830644666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.830644666666667}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.820768583333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.820768583333334}, {'config': {'heater': 90, 'bean_temp': 240.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.8108994833333325, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.8108994833333325}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.8010135499999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.8010135499999995}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.79114705, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.79114705}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.781262916666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.781262916666666}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.7713869666666673, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.7713869666666673}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.7615029333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.7615029333333334}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.751631616666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.751631616666667}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.7417473999999995, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.7417473999999995}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.731866533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.731866533333333}, {'config': {'heater': 90, 'bean_temp': 239.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.7219971000000003, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.7219971000000003}, {'config': {'heater': 90, 'bean_temp': 237.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.711849, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.711849}, {'config': {'heater': 90, 'bean_temp': 237.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.701969283333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.701969283333333}, {'config': {'heater': 90, 'bean_temp': 237.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.69209415, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.69209415}, {'config': {'heater': 90, 'bean_temp': 237.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.682214383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.682214383333333}, {'config': {'heater': 90, 'bean_temp': 237.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.6707355500000007, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.6707355500000007}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.660857449999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.660857449999999}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.65098095, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.65098095}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.6411123833333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.6411123833333336}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.6312272666666674, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.6312272666666674}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.621356266666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.621356266666667}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.6114762166666674, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.6114762166666674}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.6016053333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.6016053333333335}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5917176500000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5917176500000005}, {'config': {'heater': 90, 'bean_temp': 235.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5818463833333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5818463833333336}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.571963383333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.571963383333334}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.56209165, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.56209165}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5522068166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5522068166666667}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5423432166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5423432166666666}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5324583, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5324583}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5225734833333338, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5225734833333338}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5127127500000004, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5127127500000004}, {'config': {'heater': 90, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.5028227833333325, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.5028227833333325}, {'config': {'heater': 90, 'bean_temp': 231.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.4926774500000004, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.4926774500000004}, {'config': {'heater': 90, 'bean_temp': 231.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.4827950333333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.4827950333333337}, {'config': {'heater': 90, 'bean_temp': 231.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.4729251166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.4729251166666666}, {'config': {'heater': 90, 'bean_temp': 231.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.463046833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.463046833333334}, {'config': {'heater': 90, 'bean_temp': 231.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.453168916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.453168916666667}, {'config': {'heater': 90, 'bean_temp': 231.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.430203866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.430203866666667}, {'config': {'heater': 90, 'bean_temp': 231.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.420338966666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.420338966666666}, {'config': {'heater': 90, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.410450383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.410450383333333}, {'config': {'heater': 90, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.4005752000000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.4005752000000005}, {'config': {'heater': 90, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3906927, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3906927}, {'config': {'heater': 90, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3808176333333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3808176333333337}, {'config': {'heater': 90, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3709492, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3709492}, {'config': {'heater': 90, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3610658166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3610658166666667}, {'config': {'heater': 90, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3511879999999996, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3511879999999996}, {'config': {'heater': 90, 'bean_temp': 228.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3410362166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3410362166666667}, {'config': {'heater': 90, 'bean_temp': 228.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3311635833333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3311635833333337}, {'config': {'heater': 90, 'bean_temp': 228.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3212828666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3212828666666665}, {'config': {'heater': 90, 'bean_temp': 228.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3114094166666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3114094166666668}, {'config': {'heater': 90, 'bean_temp': 228.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.3015303166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.3015303166666667}, {'config': {'heater': 90, 'bean_temp': 228.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2916540999999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2916540999999997}, {'config': {'heater': 90, 'bean_temp': 228.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2817736833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2817736833333333}, {'config': {'heater': 90, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2718983833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2718983833333333}, {'config': {'heater': 90, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2620142000000003, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2620142000000003}, {'config': {'heater': 90, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2521387833333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2521387833333337}, {'config': {'heater': 90, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2422718, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2422718}, {'config': {'heater': 90, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2323836666666663, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2323836666666663}, {'config': {'heater': 90, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2225023166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2225023166666666}, {'config': {'heater': 90, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2126292333333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2126292333333337}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.2027551, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.2027551}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.1928726999999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.1928726999999997}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.1830023, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.1830023}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.173121316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.173121316666667}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.163244866666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.163244866666667}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.153364083333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.153364083333333}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.1434831, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.1434831}, {'config': {'heater': 90, 'bean_temp': 224.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.1336050166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.1336050166666665}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.123728166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.123728166666667}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.1138526666666673, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.1138526666666673}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.1039726000000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.1039726000000005}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.0940973166666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.0940973166666668}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.0842229833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.0842229833333334}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.07433975, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.07433975}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.0641982666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.0641982666666667}, {'config': {'heater': 90, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.0543251666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.0543251666666666}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.0444433333333327, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.0444433333333327}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.0345620166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.0345620166666665}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.024683816666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.024683816666667}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.0148092166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.0148092166666665}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 3.004929633333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 3.004929633333334}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9950524333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9950524333333335}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9851741666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9851741666666665}, {'config': {'heater': 90, 'bean_temp': 221.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9752930833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9752930833333333}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.96542165, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.96542165}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.95554405, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.95554405}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9456639499999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9456639499999997}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9357886, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9357886}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9259135666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9259135666666665}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9160321666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9160321666666666}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.9061500666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.9061500666666666}, {'config': {'heater': 90, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.89627915, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.89627915}, {'config': {'heater': 90, 'bean_temp': 217.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.8863982666666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.8863982666666668}, {'config': {'heater': 90, 'bean_temp': 217.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.8765179, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.8765179}, {'config': {'heater': 90, 'bean_temp': 217.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.866642966666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.866642966666667}, {'config': {'heater': 90, 'bean_temp': 217.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.8567611833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.8567611833333335}, {'config': {'heater': 90, 'bean_temp': 217.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.8468931833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.8468931833333335}, {'config': {'heater': 90, 'bean_temp': 217.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.837011916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.837011916666667}, {'config': {'heater': 90, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.8271317333333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.8271317333333332}, {'config': {'heater': 90, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.81725695, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.81725695}, {'config': {'heater': 90, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.8073823499999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.8073823499999997}, {'config': {'heater': 90, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.7972390666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7972390666666667}, {'config': {'heater': 90, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.7873601833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7873601833333335}, {'config': {'heater': 90, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.7774771, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7774771}, {'config': {'heater': 90, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 347.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.7676024166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7676024166666666}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.7577257333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7577257333333334}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.74784275, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.74784275}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.737970916666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.737970916666667}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.7280892, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7280892}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.7182158000000003, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7182158000000003}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.7083355333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.7083355333333334}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6984560833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6984560833333333}, {'config': {'heater': 90, 'bean_temp': 213.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6885828666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6885828666666667}, {'config': {'heater': 90, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6787055666666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6787055666666664}, {'config': {'heater': 90, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6688257500000003, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6688257500000003}, {'config': {'heater': 90, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6589436, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6589436}, {'config': {'heater': 90, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6490696166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6490696166666665}, {'config': {'heater': 90, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6391903833333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6391903833333337}, {'config': {'heater': 90, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6293112833333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6293112833333336}, {'config': {'heater': 90, 'bean_temp': 210.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.6194396333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.6194396333333336}, {'config': {'heater': 90, 'bean_temp': 210.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.609557383333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.609557383333333}, {'config': {'heater': 90, 'bean_temp': 210.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5996837, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5996837}, {'config': {'heater': 90, 'bean_temp': 210.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5897978666666663, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5897978666666663}, {'config': {'heater': 90, 'bean_temp': 210.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5799283333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5799283333333336}, {'config': {'heater': 90, 'bean_temp': 210.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5700418833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5700418833333334}, {'config': {'heater': 90, 'bean_temp': 210.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5601723, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5601723}, {'config': {'heater': 90, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5502877333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5502877333333336}, {'config': {'heater': 90, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5404642833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5404642833333333}, {'config': {'heater': 90, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 348.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.5305307666666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5305307666666668}, {'config': {'heater': 90, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.5203899333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5203899333333335}, {'config': {'heater': 90, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.5105087999999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.5105087999999998}, {'config': {'heater': 90, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.50063415, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.50063415}, {'config': {'heater': 90, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.4907542333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.4907542333333335}, {'config': {'heater': 90, 'bean_temp': 206.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.48088745, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.48088745}, {'config': {'heater': 90, 'bean_temp': 206.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.4710029666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.4710029666666666}, {'config': {'heater': 90, 'bean_temp': 206.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.4611245999999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.4611245999999998}, {'config': {'heater': 90, 'bean_temp': 206.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.451250133333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.451250133333333}, {'config': {'heater': 90, 'bean_temp': 206.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.441372633333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.441372633333333}, {'config': {'heater': 90, 'bean_temp': 206.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.43149765, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.43149765}, {'config': {'heater': 90, 'bean_temp': 206.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.42161305, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.42161305}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.4117390666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.4117390666666667}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.4018591833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.4018591833333334}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.3919795333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3919795333333336}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.38210255, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.38210255}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.372228333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.372228333333333}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.3623518166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3623518166666666}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 350.6, 'chaff_tray': 1, 'fan': 0, 'time': 2.3524719, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3524719}, {'config': {'heater': 90, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.3425907, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3425907}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.3327183666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3327183666666667}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.3228406500000003, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3228406500000003}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.3129596333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3129596333333335}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.3030853, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.3030853}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.293206566666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.293206566666667}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.2833258666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.2833258666666665}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.2734485666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.2734485666666666}, {'config': {'heater': 90, 'bean_temp': 203.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.263306366666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.263306366666667}, {'config': {'heater': 90, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.253429533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.253429533333333}, {'config': {'heater': 90, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.2435582166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.2435582166666665}, {'config': {'heater': 90, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.2336724166666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.2336724166666664}, {'config': {'heater': 90, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 352.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 2.2237941333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.2237941333333335}, {'config': {'heater': 90, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.2139232833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.2139232833333335}, {'config': {'heater': 90, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.2040452833333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.2040452833333335}, {'config': {'heater': 90, 'bean_temp': 199.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.1941642333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.1941642333333333}, {'config': {'heater': 90, 'bean_temp': 199.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.184284433333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.184284433333333}, {'config': {'heater': 90, 'bean_temp': 199.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.174407733333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.174407733333333}, {'config': {'heater': 90, 'bean_temp': 199.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.1645313, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.1645313}, {'config': {'heater': 90, 'bean_temp': 199.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.1546518333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.1546518333333333}, {'config': {'heater': 90, 'bean_temp': 199.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.1447744, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.1447744}, {'config': {'heater': 90, 'bean_temp': 199.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.13489435, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.13489435}, {'config': {'heater': 90, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.1250227, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.1250227}, {'config': {'heater': 90, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 354.2, 'chaff_tray': 1, 'fan': 0, 'time': 2.115146983333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.115146983333333}, {'config': {'heater': 90, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.1052640166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.1052640166666667}, {'config': {'heater': 90, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.0953909666666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.0953909666666664}, {'config': {'heater': 90, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.0855172666666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.0855172666666664}, {'config': {'heater': 90, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.075628233333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.075628233333333}, {'config': {'heater': 90, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.065763533333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.065763533333333}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.0558710166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.0558710166666665}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.0459967666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.0459967666666667}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.036117733333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.036117733333333}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 356.0, 'chaff_tray': 1, 'fan': 0, 'time': 2.0262415, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.0262415}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.01636625, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.01636625}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 2.006489766666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 2.006489766666667}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9966070166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9966070166666667}, {'config': {'heater': 90, 'bean_temp': 195.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9864728333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9864728333333335}, {'config': {'heater': 90, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9765983333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9765983333333335}, {'config': {'heater': 90, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9667111166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9667111166666666}, {'config': {'heater': 90, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9568357333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9568357333333335}, {'config': {'heater': 90, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9469556166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9469556166666666}, {'config': {'heater': 90, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9370784166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9370784166666666}, {'config': {'heater': 90, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 357.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.9272020333333328, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9272020333333328}, {'config': {'heater': 90, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.9173191333333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9173191333333337}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.9074416500000004, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.9074416500000004}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.8975702, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8975702}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.8876866833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8876866833333334}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.8778148, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8778148}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.8679325666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8679325666666666}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 359.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.8580594166666669, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8580594166666669}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.8481772833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8481772833333334}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.8382990833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8382990833333333}, {'config': {'heater': 90, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.8284237166666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8284237166666668}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.8185491333333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8185491333333337}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.8086705833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.8086705833333334}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.7987926833333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7987926833333332}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 361.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.7889119000000004, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7889119000000004}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.7790380499999996, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7790380499999996}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.7691568166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7691568166666665}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.7592767666666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7592767666666664}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.7494069666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7494069666666667}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.7395295000000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7395295000000002}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.7296423333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7296423333333335}, {'config': {'heater': 90, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 363.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.7197653833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7197653833333333}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.7098932833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7098932833333333}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.7000174499999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.7000174499999998}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.6901353833333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6901353833333332}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.6799875833333338, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6799875833333338}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.670109633333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.670109633333333}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 365.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.6602367166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6602367166666667}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.6503583833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6503583833333333}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.6404775833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6404775833333334}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.630598466666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.630598466666667}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 366.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.6207281333333339, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6207281333333339}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.6108460499999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6108460499999997}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.6009675999999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.6009675999999997}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.591085933333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.591085933333333}, {'config': {'heater': 90, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.5812107499999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5812107499999999}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 368.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.5713343499999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5713343499999999}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.5614569166666663, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5614569166666663}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.5515752333333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5515752333333332}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.5417051166666669, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5417051166666669}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.5318210833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5318210833333334}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 370.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.5219454666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5219454666666667}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.5120724166666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.5120724166666668}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.50220195, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.50220195}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.4923114666666661, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4923114666666661}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.4824805833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4824805833333334}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.4725658999999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4725658999999998}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 372.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.4626820833333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4626820833333332}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.4528011000000003, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4528011000000003}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.4429191000000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4429191000000001}, {'config': {'heater': 90, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.4330463, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4330463}, {'config': {'heater': 89, 'bean_temp': 186.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.4231693500000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4231693500000002}, {'config': {'heater': 86, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.4132902333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4132902333333335}, {'config': {'heater': 85, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.4034091333333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.4034091333333332}, {'config': {'heater': 83, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.3932648333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.3932648333333333}, {'config': {'heater': 80, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.3834224666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.3834224666666666}, {'config': {'heater': 79, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.3735189499999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.3735189499999998}, {'config': {'heater': 38, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.3636319000000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.3636319000000001}, {'config': {'heater': 0, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.3537725333333337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.3537725333333337}, {'config': {'heater': 0, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.34388, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.34388}, {'config': {'heater': 0, 'bean_temp': 188.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.333999316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.333999316666667}, {'config': {'heater': 0, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.3241253666666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.3241253666666664}, {'config': {'heater': 0, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.314246316666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.314246316666667}, {'config': {'heater': 0, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.3043736166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.3043736166666666}, {'config': {'heater': 0, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.294493216666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.294493216666667}, {'config': {'heater': 0, 'bean_temp': 190.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.2846159166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2846159166666666}, {'config': {'heater': 0, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.274732366666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.274732366666667}, {'config': {'heater': 0, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.2648561333333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2648561333333332}, {'config': {'heater': 0, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.2549869, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2549869}, {'config': {'heater': 0, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.2451124833333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2451124833333336}, {'config': {'heater': 0, 'bean_temp': 192.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 1.2352273666666664, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2352273666666664}, {'config': {'heater': 0, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.2253497333333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2253497333333332}, {'config': {'heater': 0, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.2154670333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2154670333333333}, {'config': {'heater': 0, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.2056083333333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.2056083333333332}, {'config': {'heater': 0, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.1957213000000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1957213000000002}, {'config': {'heater': 0, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.1858387000000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1858387000000001}, {'config': {'heater': 0, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 1.1759611166666661, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1759611166666661}, {'config': {'heater': 0, 'bean_temp': 194.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.1660811666666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1660811666666668}, {'config': {'heater': 0, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.1562084666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1562084666666665}, {'config': {'heater': 0, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.146337, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.146337}, {'config': {'heater': 0, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.1361867833333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1361867833333332}, {'config': {'heater': 0, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.1263104166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1263104166666666}, {'config': {'heater': 0, 'bean_temp': 197.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.1164286999999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1164286999999997}, {'config': {'heater': 0, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 1.1068196833333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.1068196833333332}, {'config': {'heater': 0, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.0966707333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0966707333333336}, {'config': {'heater': 0, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.08679505, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.08679505}, {'config': {'heater': 0, 'bean_temp': 201.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.0769151166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0769151166666666}, {'config': {'heater': 0, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.067046733333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.067046733333333}, {'config': {'heater': 0, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.0571631166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0571631166666666}, {'config': {'heater': 0, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.0472834333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0472834333333334}, {'config': {'heater': 0, 'bean_temp': 204.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 1.0374019333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0374019333333333}, {'config': {'heater': 0, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.0275320666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0275320666666667}, {'config': {'heater': 0, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.0176556666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0176556666666667}, {'config': {'heater': 0, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 1.0077757166666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 1.0077757166666665}, {'config': {'heater': 0, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.9978935333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9978935333333334}, {'config': {'heater': 0, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.9880168500000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9880168500000002}, {'config': {'heater': 0, 'bean_temp': 208.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.9781356833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9781356833333334}, {'config': {'heater': 0, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.9682608333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9682608333333333}, {'config': {'heater': 0, 'bean_temp': 212.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.9583828333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9583828333333335}, {'config': {'heater': 0, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.9485019166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9485019166666666}, {'config': {'heater': 0, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.9386313333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9386313333333334}, {'config': {'heater': 0, 'bean_temp': 215.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.9287472666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9287472666666667}, {'config': {'heater': 0, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.9188764833333332, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9188764833333332}, {'config': {'heater': 0, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.9089954166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.9089954166666667}, {'config': {'heater': 0, 'bean_temp': 219.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8991214666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8991214666666667}, {'config': {'heater': 0, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8892403666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8892403666666666}, {'config': {'heater': 0, 'bean_temp': 222.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8793657166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8793657166666666}, {'config': {'heater': 0, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8694856833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8694856833333333}, {'config': {'heater': 0, 'bean_temp': 226.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8596096166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8596096166666667}, {'config': {'heater': 0, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8497264999999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8497264999999998}, {'config': {'heater': 0, 'bean_temp': 230.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8398534833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8398534833333333}, {'config': {'heater': 0, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.8299791166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8299791166666666}, {'config': {'heater': 0, 'bean_temp': 233.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.8198304500000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8198304500000002}, {'config': {'heater': 0, 'bean_temp': 237.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.8099545666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8099545666666665}, {'config': {'heater': 0, 'bean_temp': 237.20000000000002, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.8000716666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.8000716666666667}, {'config': {'heater': 0, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7902015999999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7902015999999998}, {'config': {'heater': 0, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7803198833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7803198833333334}, {'config': {'heater': 0, 'bean_temp': 242.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7704413166666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7704413166666666}, {'config': {'heater': 0, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7605643, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7605643}, {'config': {'heater': 0, 'bean_temp': 248.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7506890333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7506890333333334}, {'config': {'heater': 0, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.74081065, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.74081065}, {'config': {'heater': 0, 'bean_temp': 253.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7309305666666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7309305666666668}, {'config': {'heater': 0, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7210523666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7210523666666666}, {'config': {'heater': 0, 'bean_temp': 258.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7111784000000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7111784000000001}, {'config': {'heater': 0, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.7013006833333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.7013006833333333}, {'config': {'heater': 0, 'bean_temp': 264.20000000000005, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.6914193, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6914193}, {'config': {'heater': 0, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.6815382499999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6815382499999998}, {'config': {'heater': 0, 'bean_temp': 269.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.6716645666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6716645666666667}, {'config': {'heater': 0, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.6617896166666668, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6617896166666668}, {'config': {'heater': 0, 'bean_temp': 275.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.65191165, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.65191165}, {'config': {'heater': 0, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.6420341500000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6420341500000002}, {'config': {'heater': 0, 'bean_temp': 280.4, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.63215475, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.63215475}, {'config': {'heater': 0, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.6222790333333335, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6222790333333335}, {'config': {'heater': 0, 'bean_temp': 287.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.6123950499999999, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6123950499999999}, {'config': {'heater': 0, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.6025167, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.6025167}, {'config': {'heater': 0, 'bean_temp': 294.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5926456000000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5926456000000002}, {'config': {'heater': 0, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5824978666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5824978666666667}, {'config': {'heater': 0, 'bean_temp': 302.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5726238333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5726238333333333}, {'config': {'heater': 0, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5627414666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5627414666666666}, {'config': {'heater': 0, 'bean_temp': 309.2, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5528638666666665, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5528638666666665}, {'config': {'heater': 0, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5429959500000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5429959500000001}, {'config': {'heater': 0, 'bean_temp': 316.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.53310875, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.53310875}, {'config': {'heater': 0, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.52322965, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.52322965}, {'config': {'heater': 0, 'bean_temp': 323.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5133579500000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5133579500000001}, {'config': {'heater': 0, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.5034803333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.5034803333333333}, {'config': {'heater': 0, 'bean_temp': 330.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.49360041666666676, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.49360041666666676}, {'config': {'heater': 0, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.48371893333333316, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.48371893333333316}, {'config': {'heater': 0, 'bean_temp': 338.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.4738434, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.4738434}, {'config': {'heater': 100, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.4639662666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.4639662666666666}, {'config': {'heater': 100, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.4540885000000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.4540885000000001}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.44420780000000004, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.44420780000000004}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.43433428333333324, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.43433428333333324}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 392.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.42446323333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.42446323333333336}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.4145833333333333, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.4145833333333333}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.40469745, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.40469745}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.39482438333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.39482438333333336}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.38494813333333355, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.38494813333333355}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 390.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.37506931666666676, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.37506931666666676}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.36518835000000016, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.36518835000000016}, {'config': {'heater': 100, 'bean_temp': 352.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.35531366666666675, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.35531366666666675}, {'config': {'heater': 100, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.3454373500000001, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.3454373500000001}, {'config': {'heater': 100, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 388.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.3355554833333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.3355554833333334}, {'config': {'heater': 100, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.32541128333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.32541128333333336}, {'config': {'heater': 100, 'bean_temp': 350.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.3155298666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.3155298666666666}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.3056577500000002, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.3056577500000002}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.29577845, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.29577845}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 386.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.2858992, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.2858992}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.2760258, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.2760258}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.26614994999999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.26614994999999997}, {'config': {'heater': 100, 'bean_temp': 348.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.2562723166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.2562723166666667}, {'config': {'heater': 100, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 384.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.24638834999999992, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.24638834999999992}, {'config': {'heater': 100, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.23651546666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.23651546666666667}, {'config': {'heater': 100, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.22663771666666666, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.22663771666666666}, {'config': {'heater': 100, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.21675584999999997, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.21675584999999997}, {'config': {'heater': 100, 'bean_temp': 347.0, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 383.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.20687696666666655, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.20687696666666655}, {'config': {'heater': 100, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.1969987333333334, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.1969987333333334}, {'config': {'heater': 100, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.18712560000000011, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.18712560000000011}, {'config': {'heater': 100, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.17724241666666662, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.17724241666666662}, {'config': {'heater': 100, 'bean_temp': 345.2, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.16736523333333353, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.16736523333333353}, {'config': {'heater': 100, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 381.2, 'chaff_tray': 1, 'fan': 0, 'time': 0.15749544999999987, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.15749544999999987}, {'config': {'heater': 100, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.1476168166666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.1476168166666667}, {'config': {'heater': 100, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.13773593333333323, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.13773593333333323}, {'config': {'heater': 100, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.12785374999999988, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.12785374999999988}, {'config': {'heater': 100, 'bean_temp': 343.40000000000003, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 379.40000000000003, 'chaff_tray': 1, 'fan': 0, 'time': 0.11798004999999989, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.11798004999999989}, {'config': {'heater': 100, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.10810506666666675, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.10810506666666675}, {'config': {'heater': 100, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.09822116666666658, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.09822116666666658}, {'config': {'heater': 100, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.08834986666666667, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.08834986666666667}, {'config': {'heater': 100, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.07820033333333343, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.07820033333333343}, {'config': {'heater': 100, 'bean_temp': 341.6, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 377.6, 'chaff_tray': 1, 'fan': 0, 'time': 0.06832711666666658, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.06832711666666658}, {'config': {'heater': 100, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.05844880000000008, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.05844880000000008}, {'config': {'heater': 100, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.048568733333333336, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.048568733333333336}, {'config': {'heater': 100, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.03868538333333338, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.03868538333333338}, {'config': {'heater': 100, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 375.8, 'chaff_tray': 1, 'fan': 0, 'time': 0.02880919999999998, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.02880919999999998}, {'config': {'heater': 100, 'bean_temp': 339.8, 'drum_motor': 1, 'main_fan': 0, 'environment_temp': 374.0, 'chaff_tray': 1, 'fan': 0, 'time': 0.01893750000000005, 'solenoid': 0, 'cooling_motor': 0}, 'time': 0.01893750000000005}]

        while not self._q.empty():
            self._config = self._q.get()

        while not self.exit.is_set():
            self._log.debug("Thread pulse")
            self._config = data.pop()
            self._log.debug(self._config)
            self._cb(self._config['config'])  # This gives us a way to know when to read

            if self.cooldown.is_set():
                self._log.debug("Cool down process triggered")
                self._config['drum_motor'] = 0
                self._config['heater'] = 0
                self._config['solenoid'] = 1
                self._config['cooling_motor'] = 1
                self._config['main_fan'] = 10

            time.sleep(.5)

    def drop(self):
        """Register a drop event to begin the cool-down process.

        :returns: None
        """
        self._log.debug("Dropping the coffee")
        self.cooldown.set()

    def shutdown(self):
        """Register a shutdown event."""
        self._log.debug("Shutdown initiated")
        self.exit.set()
